==> haskell-checkers-0.6.0-251.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-HrN3HZpjPFoJTMGFUQjllp
key:                  checkers-0.6.0-HrN3HZpjPFoJTMGFUQjllp
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  ba00d12ab2bcb7d58c905fa218203f7e
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/checkers-0.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-HrN3HZpjPFoJTMGFUQjllp
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L array-0.5.6.0
    base-4.18.2.1 random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.6.0-252-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-Ao9kGeq2Js8Kb9sWX75DgM
key:                  checkers-0.6.0-Ao9kGeq2Js8Kb9sWX75DgM
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  ba03a472e74e6369acfc6883a6f26ae0
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/checkers-0.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-Ao9kGeq2Js8Kb9sWX75DgM
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS array-0.5.6.0
    base-4.18.2.1 random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
